#!/usr/bin/python

import smbus
import time

bus = smbus.SMBus(1) #Depends on which I2C bus is in use

DEVICE_ADDRESS = 0x3E #Configured ATmega328P I2C address

################### Register locations ##############################
DEVICE_SERVO_0 = 0x00
DEVICE_SERVO_1 = 0x01
DEVICE_SERVO_2 = 0x02
DEVICE_SERVO_3 = 0x03
DEVICE_SERVO_4 = 0x04

SERVO0_EN = 0x06

################### Feeding constants ###############################

# Center position is 91/92, starts moving clockwise at 90, and counter-clockwise at 93

FEED_TIME = 5.0				# Time to auger food out
WiGGLE_COUNT = 2			# Number of wiggles of the food dislodger

SERVO_REVERSE = 20
SERVO_FORWARD = 235
SERVO_NEUTRAL = 91
SERVO_NUMBER = DEVICE_SERVO_0

SERVO_WIGGLE_REVERSE = 0
SERVO_WIGGLE_FORWARD = 255
SERVO_WIGGLE_NEUTRAL = 128
SERVO_NUMBER_WIGGLE = DEVICE_SERVO_1

################# Start feeding cycle ##############################

# Enable servo 0
bus.write_byte_data(DEVICE_ADDRESS, SERVO0_EN, 1)

# Run forwards for an amount of time which sets how much food is given
bus.write_byte_data(DEVICE_ADDRESS, SERVO_NUMBER, SERVO_FORWARD)

# Split the feed-time into a number of servo wiggles
stop_time_for_each_wiggle = FEED_TIME / (2 * WiGGLE_COUNT)

for x in xrange(0, WiGGLE_COUNT):
	bus.write_byte_data(DEVICE_ADDRESS, SERVO_NUMBER_WIGGLE, SERVO_WIGGLE_FORWARD)
	time.sleep(stop_time_for_each_wiggle)
	bus.write_byte_data(DEVICE_ADDRESS, SERVO_NUMBER_WIGGLE, SERVO_WIGGLE_REVERSE)
	time.sleep(stop_time_for_each_wiggle)

# Return the servo to the neutral posistion
bus.write_byte_data(DEVICE_ADDRESS, SERVO_NUMBER, SERVO_NEUTRAL)
time.sleep(0.2)
bus.write_byte_data(DEVICE_ADDRESS, SERVO_NUMBER_WIGGLE, SERVO_WIGGLE_NEUTRAL)

# Disable servo 0
#bus.write_byte_data(DEVICE_ADDRESS, SERVO0_EN, 0)

################# Log the feeding time #############################

# Get time stamp and make string
system_time = time.localtime()
time_string = time.strftime("%a, %d %b %Y %H:%M:%S", system_time)

#print "Time string:\n"
#print(time_string)

# Save log file
file = open("feed_stamps.txt", "w")
file.write("Last feeding at:\n")
file.write(time_string)
file.close()


