import smbus
import time

bus = smbus.SMBus(1) #Depends on which I2C bus is in use

DEVICE_ADDRESS_EEPROM = 0x57	#MCP79410 EEPROM I2C address
DEVICE_ADDRESS_SRAM = 0x6F	#MCP79410 SRAM I2C address

############ MCP79410 register locations #######################
#Time registers
DEVICE_SECONDS = 0x00
DEVICE_MINUTES = 0x01
DEVICE_HOURS = 0x02
DEVICE_DAY = 0x03		# 1-7
DEVICE_DATE = 0x04		# 1-31
DEVICE_MONTH = 0x05
DEVICE_YEAR = 0x06
#Control registers
DEVICE_CONTROL = 0x07
DEVICE_CALIBRATION = 0x08
#Time stamp power down
DEVICE_MINUTE_PD = 0x18
DEVICE_HOUR_PD = 0x19
DEVICE_DATE_PD = 0x1A
DEVICE_MONTH_PD = 0x1B
#Time stamp power up
DEVICE_MINUTE_PU = 0x1C
DEVICE_HOUR_PU = 0x1D
DEVICE_DATE_PU = 0x1E
DEVICE_MONTH_PU = 0x1F

################### Define some common functions ###################

# Read minutes (or seconds)
def read_minutes(address):
	minutes = bus.read_byte_data(DEVICE_ADDRESS_SRAM, address)
	bcd_minutes_ones = (minutes & 0x0F)
	bcd_minutes_tens = (minutes & 0b01110000)
	bcd_minutes_tens = (bcd_minutes_tens >> 4)
	return (bcd_minutes_ones + (10*bcd_minutes_tens))

# Read hours
def read_hours(address):
	hours = bus.read_byte_data(DEVICE_ADDRESS_SRAM, address)
	bcd_hours_ones = (hours & 0x0F)
	bcd_hours_tens = (hours & 0x30)
	bcd_hours_tens = (bcd_hours_tens >> 4)
	return (bcd_hours_ones + (10*bcd_hours_tens))

# Read day of month
def read_day(address):
	date = bus.read_byte_data(DEVICE_ADDRESS_SRAM, address)
	bcd_date_ones = (date & 0x0F)
	bcd_date_tens = (date & 0x30)
	bcd_date_tens = (bcd_date_tens >> 4)
	return (bcd_date_ones + (10*bcd_date_tens))

# Read current month
def read_month(address):
	month = bus.read_byte_data(DEVICE_ADDRESS_SRAM, address)
	bcd_month_ones = (month & 0x0F)
	bcd_month_tens = (month & 0x10)
	bcd_month_tens = (bcd_month_tens >> 4)
	return (bcd_month_ones + (10*bcd_month_tens))

################# Get the current time ##############################

seconds = read_minutes(DEVICE_SECONDS)
minutes = read_minutes(DEVICE_MINUTES)
hours = read_hours(DEVICE_HOURS)
date = read_day(DEVICE_DATE)
month = read_month(DEVICE_MONTH)

# Read day of week
weekday = read_hours(DEVICE_DAY) 
weekday = (weekday & 0x07)

#Read current year
year = bus.read_byte_data(DEVICE_ADDRESS_SRAM, DEVICE_YEAR)
bcd_year_ones = (year & 0x0F)
bcd_year_tens = (year & 0xF0)
bcd_year_tens = (bcd_year_tens >> 4)
year = bcd_year_ones + (10*bcd_year_tens)

# Convert to time struct
l = list(time.localtime())
l[5] = seconds
l[4] = minutes
l[3] = hours
l[6] = (weekday - 1)
l[2] = date
l[1] = month
l[0] = year
rtc_time = time.struct_time(l)

################ Display the time #######################################
# RTC time
print "RTC time:"
#time_string = time.strftime("%a, %d %b %Y %H:%M:%S", rtc_time)
time_string = time.strftime("%d %b %Y %H:%M:%S", rtc_time)
print(time_string)

#print "%d:%d:%d." %(hours, minutes, seconds)
#print "On the %d. of the %d. month, year %d." %(date, month, year)
